![build](https://github.com/shinolab/pyautd/workflows/build/badge.svg)
![Publish to PyPI](https://github.com/shinolab/pyautd/workflows/Publish%20to%20PyPI/badge.svg)

# pyautd3

[autd3 library](https://github.com/shinolab/autd3-library-software) for python3.6+

version: 1.4.0

## :hammer_and_wrench: Install

```
pip install pyautd3
```
or from this repository
```
pip install git+https://github.com/shinolab/pyautd.git
```

## :ballot_box_with_check: Requirements

If you use Windows and `soem_link`, install [Npcap](https://nmap.org/npcap/) with WinPcap API-compatible mode (recomennded) or [WinPcap](https://www.winpcap.org/).

If you are using Linux/macOS, you may need to install and run pyautd3 as root. 
```
sudo pip install pyautd3
sudo python
>>> import pyautd3
``` 

## :beginner: Example

see [example](./example)

## :copyright: LICENSE

See [LICENSE](./LICENSE) and [NOTICE](./NOTICE).

# Author

Shun Suzuki, 2020-2021
